==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algeline/xerbla.f <==
      SUBROUTINE XERBLA( SRNAME, INFO )
C----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGELINE  DATE 12/12/2002   AUTEUR MCOURTOI M.COURTOIS 
C ======================================================================
C COPYRIGHT (C) LAPACK
C ======================================================================
C
C     SUBROUTINE LAPACK DE TRAITEMENT DES ERREURS.
C-----------------------------------------------------------------------
C  -- LAPACK AUXILIARY ROUTINE (VERSION 2.0) --
C     UNIV. OF TENNESSEE, UNIV. OF CALIFORNIA BERKELEY, NAG LTD.,
C     COURANT INSTITUTE, ARGONNE NATIONAL LAB, AND RICE UNIVERSITY
C     SEPTEMBER 30, 1994
C
C  PURPOSE
C  =======
C
C  XERBLA  IS AN ERROR HANDLER FOR THE LAPACK ROUTINES.
C  IT IS CALLED BY AN LAPACK ROUTINE IF AN INPUT PARAMETER HAS AN
C  INVALID VALUE.  A MESSAGE IS PRINTED AND EXECUTION STOPS.
C
C  INSTALLERS MAY CONSIDER MODIFYING THE STOP STATEMENT IN ORDER TO
C  CALL SYSTEM-SPECIFIC EXCEPTION-HANDLING FACILITIES.
C
C  ARGUMENTS
C  =========
C
C  SRNAME  (INPUT) CHARACTER*6
C          THE NAME OF THE ROUTINE WHICH CALLED XERBLA.
C
C  INFO    (INPUT) INTEGER
C          THE POSITION OF THE INVALID PARAMETER IN THE PARAMETER LIST
C          OF THE CALLING ROUTINE.
C
C ASTER INFORMATION
C 11/01/2000 TOILETTAGE DU FORTRAN SUIVANT LES REGLES ASTER,
C            MSGS GERES PAR UTDEBM, UTIMPI, UTIMPK, UTFINM,
C            AU LIEU DE WRITE(*,FMT=9999)SRNAME,INFO
C            IMPLICIT NONE
C----------------------------------------------------------------------
C CORPS DU PROGRAMME
      IMPLICIT NONE

C     .. SCALAR ARGUMENTS ..
      CHARACTER*6        SRNAME
      INTEGER            INFO
C     ..
C     .. EXECUTABLE STATEMENTS ..
C
      CALL UTDEBM('F','XERBLA','ERREUR LAPACK')
      CALL UTIMPK('L',' AU NIVEAU DE LA ROUTINE ',1,SRNAME)
      CALL UTIMPI('L',' LE PARAMETRE NUMERO ',1,INFO)
      CALL UTIMPI('S',' N''A PAS UNE VALEUR COHERENTE',0,INFO)
      CALL UTFINM()
C
C     END OF XERBLA
C
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algeline/xerbla.f <==
      SUBROUTINE XERBLA( SRNAME, INFO )
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGELINE  DATE 31/01/2005   AUTEUR REZETTE C.REZETTE 
C----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C ======================================================================
C COPYRIGHT (C) LAPACK / BLAS
C ======================================================================
C
C     SUBROUTINE LAPACK / BLAS DE TRAITEMENT DES ERREURS.
C-----------------------------------------------------------------------
C  -- LAPACK AUXILIARY ROUTINE (VERSION 2.0) --
C     UNIV. OF TENNESSEE, UNIV. OF CALIFORNIA BERKELEY, NAG LTD.,
C     COURANT INSTITUTE, ARGONNE NATIONAL LAB, AND RICE UNIVERSITY
C     SEPTEMBER 30, 1994
C
C  PURPOSE
C  =======
C
C  XERBLA  IS AN ERROR HANDLER FOR THE LAPACK ROUTINES.
C  IT IS CALLED BY AN LAPACK ROUTINE IF AN INPUT PARAMETER HAS AN
C  INVALID VALUE.  A MESSAGE IS PRINTED AND EXECUTION STOPS.
C
C  INSTALLERS MAY CONSIDER MODIFYING THE STOP STATEMENT IN ORDER TO
C  CALL SYSTEM-SPECIFIC EXCEPTION-HANDLING FACILITIES.
C
C  ARGUMENTS
C  =========
C
C  SRNAME  (INPUT) CHARACTER*6
C          THE NAME OF THE ROUTINE WHICH CALLED XERBLA.
C
C  INFO    (INPUT) INTEGER
C          THE POSITION OF THE INVALID PARAMETER IN THE PARAMETER LIST
C          OF THE CALLING ROUTINE.
C
C ASTER INFORMATION
C 11/01/2000 TOILETTAGE DU FORTRAN SUIVANT LES REGLES ASTER,
C            MSGS GERES PAR UTDEBM, UTIMPI, UTIMPK, UTFINM,
C            AU LIEU DE WRITE(*,FMT=9999)SRNAME,INFO
C            IMPLICIT NONE
C----------------------------------------------------------------------
C CORPS DU PROGRAMME
      IMPLICIT NONE

C     .. SCALAR ARGUMENTS ..
      CHARACTER*6        SRNAME
      INTEGER            INFO
C     ..
C     .. EXECUTABLE STATEMENTS ..
C
      CALL UTDEBM('F','XERBLA','ERREUR LAPACK (OU BLAS)')
      CALL UTIMPK('L',' AU NIVEAU DE LA ROUTINE ',1,SRNAME)
      CALL UTIMPI('L',' LE PARAMETRE NUMERO ',1,INFO)
      CALL UTIMPI('S',' N''A PAS UNE VALEUR COHERENTE',0,INFO)
      CALL UTFINM()
C
C     END OF XERBLA
C
      END
